## History

### 0.2 (2021-01-10)
* Bump version.

### 0.1.15 (2021-01-10)

* Fork with minor fixes.
* Update to bump2version.

### 0.1.12 (2016-08-15)

* Readline is optional because of MacOS compat

### 0.1.11 (2016-08-15)

* Submodules import
* multiple 'as' names

### 0.1.10 (2016-07-04)

* Bpython added

### 0.1.9 (2016-07-03)

* Bpython added

### 0.1.8 (2016-07-03)

* Python 3 dict fixes

### 0.1.7 (2016-06-26)

* exec bug fix for py3

### 0.1.6 (2016-06-26)

* exec bug fix

### 0.1.5 (2016-06-25)

* added support to commands collector (see quokka cms)

### 0.1.4 (2016-06-22)

* Fix missing deps

### 0.1.3 (2016-06-19)

* Support to function_commands

### 0.1.2 (2016-06-17)

* Support to inline_commands

### 0.1.1 (2016-06-14)

* Support to custom and hidden manage_file

### 0.1.0 (2016-06-09)

* First release on PyPI.
